@@ -1,3 +1,18 @@
+
+test_that("expect_no_* conditions behave as expected", {
+
+  # base R
+  expect_snapshot_failure(expect_no_error(stop("error")))
+  expect_snapshot_failure(expect_no_warning(warning("warning")))
+  expect_snapshot_failure(expect_no_message(message("message")))
+
+  # rlang equivalents
+  expect_snapshot_failure(expect_no_error(abort("error")))
+  expect_snapshot_failure(expect_no_warning(warn("warning")))
+  expect_snapshot_failure(expect_no_message(inform("message")))
+
+})
+
 test_that("unmatched conditions bubble up", {
   expect_error(expect_no_error(abort("foo"), message = "bar"), "foo")
   expect_warning(expect_no_warning(warn("foo"), message = "bar"), "foo")
